==> flutter_currency_picker-1.3.2.tar.gz: lib/gen_l10n/app_localization_uz.dart <==
import 'app_localization.dart';

/// The translations for Uzbek (`uz`).
class AppLocalizationsUz extends AppLocalizations {
  AppLocalizationsUz([String locale = 'uz']) : super(locale);

  @override
  String get currencyUSD => 'Amerika Qo\'shma Shtatlari Dollari';

  @override
  String get currencyEUR => 'Evro';

  @override
  String get currencyJPY => 'Yapon iyeni';

  @override
  String get currencyGBP => 'Britaniya funti';

  @override
  String get currencyAUD => 'Avstraliya dollari';

  @override
  String get currencyCAD => 'Kanada dollari';

  @override
  String get currencyCHF => 'Shveytsariya franki';

  @override
  String get currencyCNY => 'Xitoy yuan renminbi';

  @override
  String get currencyHKD => 'Gongkong dollari';

  @override
  String get currencyNZD => 'Yangi Zelandiya dollari';

  @override
  String get currencySEK => 'Shvetsiya kronasi';

  @override
  String get currencyKRW => 'Janubiy Koreya von';

  @override
  String get currencySGD => 'Singapur dollari';

  @override
  String get currencyNOK => 'Norvegiya kroni';

  @override
  String get currencyMXN => 'Meksika pesosi';

  @override
  String get currencyINR => 'Hindiston rupisi';

  @override
  String get currencyRUB => 'Rossiya rubli';

  @override
  String get currencyZAR => 'Janubiy Afrika Randi';

  @override
  String get currencyTRY => 'Turk lirasi';

  @override
  String get currencyBRL => 'Braziliya reali';

  @override
  String get currencyTWD => 'Tayvan yangi dollari';

  @override
  String get currencyDKK => 'Daniya kroni';

  @override
  String get currencyPLN => 'Polsha zlotisi';

  @override
  String get currencyTHB => 'Tailand baht';

  @override
  String get currencyIDR => 'Indoneziya rupiyasi';

  @override
  String get currencyHUF => 'Vengriya forinti';

  @override
  String get currencyCZK => 'Chexiya Korunasi';

  @override
  String get currencyILS => 'Isroil shekeli';

  @override
  String get currencyCLP => 'Chili pesosi';

  @override
  String get currencyPHP => 'Filippin peso';

  @override
  String get currencyAED => 'Amirati Dirhami';

  @override
  String get currencyCOP => 'Kolumbiya Peso';

  @override
  String get currencySAR => 'Saudiya Arabistoni Riyali';

  @override
  String get currencyMYR => 'Malayziya ringgiti';

  @override
  String get currencyRON => 'Ruminiya Leu';

  @override
  String get currencyAFN => 'Afg\'oniston afg\'oni';

  @override
  String get currencyALL => 'Alban leki';

  @override
  String get currencyDZD => 'Jazoir dinori';

  @override
  String get currencyARS => 'Argentina peso';

  @override
  String get currencyAMD => 'Arman drami';

  @override
  String get currencyAZN => 'Ozarbayjon manati';

  @override
  String get currencyBHD => 'Bahrayn dinori';

  @override
  String get currencyBDT => 'Bangladeshi Taka';

  @override
  String get currencyBBD => 'Barbados dollari';

  @override
  String get currencyBYN => 'Belarus rubli';

  @override
  String get currencyBZD => 'Beliz Dollari';

  @override
  String get currencyBMD => 'Bermud dollari';

  @override
  String get currencyBTN => 'Butan ngultrum';

  @override
  String get currencyBOB => 'Boliviya Boliviyano';

  @override
  String get currencyBAM => 'Bosniya va Gertsegovina konvertatsiya qilinadigan belgisi';

  @override
  String get currencyBWP => 'Botsvana pulasi';

  @override
  String get currencyBND => 'Bruney Dorussalom dollari';

  @override
  String get currencyBGN => 'Bolgariya Levi';

  @override
  String get currencyBIF => 'Burundi franki';

  @override
  String get currencyKHR => 'Kambodja rieli';

  @override
  String get currencyKYD => 'Kayman orollari dollari';

  @override
  String get currencyXAF => 'Markaziy Afrika CFA franki';

  @override
  String get currencyXOF => 'UEMOA CFA frank';

  @override
  String get currencyCDF => 'Kongo franki';

  @override
  String get currencyCRC => 'Kosta-Rika kolon';

  @override
  String get currencyDOP => 'Dominikan Respublikasi pesosi';

  @override
  String get currencyEGP => 'Misr funti';

  @override
  String get currencyETB => 'Efiopiya birri';

  @override
  String get currencyGMD => 'Gambiya dalasi';

  @override
  String get currencyGEL => 'Gruziya larisi';

  @override
  String get currencyGHS => 'Gana Sedi';

  @override
  String get currencyGTQ => 'Gvatemala quetzali';

  @override
  String get currencyGYD => 'Guyana dollari';

  @override
  String get currencyHTG => 'Gaiti gourde';

  @override
  String get currencyISK => 'Islandiya kronasi';

  @override
  String get currencyJMD => 'Yamayka dollari';

  @override
  String get currencyJOD => 'Iordaniya dinori';

  @override
  String get currencyKZT => 'Qozog\'iston tengesi';

  @override
  String get currencyKES => 'Keniya shillingi';

  @override
  String get currencyKWD => 'Quvayt dinari';

  @override
  String get currencyKGS => 'Qirg\'iziston so\'mi';

  @override
  String get currencyUZS => 'O\'zbekiston so\'mi';

  @override
  String get currencyLAK => 'Laos Kipi';

  @override
  String get currencyLRD => 'Liberiya dollari';

  @override
  String get currencyMKD => 'Makedoniya Denar';

  @override
  String get currencyMWK => 'Malavi kvacha';

  @override
  String get currencyMUR => 'Mavrikiy rupisi';

  @override
  String get currencyMDL => 'Moldova leyi';

  @override
  String get currencyMNT => 'Mo\'g\'uliston Tug\'rik';

  @override
  String get currencyMAD => 'Marokash dirhami';

  @override
  String get currencyMZN => 'Mozambik Metikali';

  @override
  String get currencyMMK => 'Myanma kyati';

  @override
  String get currencyNAD => 'Namibiya dollari';

  @override
  String get currencyNPR => 'Nepal rupisi';

  @override
  String get currencyNIO => 'Nikaragua Kordoba';

  @override
  String get currencyNGN => 'Nigeriya Naira';

  @override
  String get currencyOMR => 'Ummon riali';

  @override
  String get currencyPKR => 'Pokiston rupisi';

  @override
  String get currencyPGK => 'Papua-Yangi Gvineya Kinasi';

  @override
  String get currencyPYG => 'Paragvay Guarani';

  @override
  String get currencyPEN => 'Peru Sol';

  @override
  String get currencyQAR => 'Qatar riyali';

  @override
  String get currencyRWF => 'Ruanda franki';

  @override
  String get currencyRSD => 'Serbiya Dinari';

  @override
  String get currencySCR => 'Seychellois rupisi';

  @override
  String get currencySOS => 'Somali shillingi';

  @override
  String get currencyLKR => 'Shri-Lanka rupisi';

  @override
  String get currencySRD => 'Surinam dollari';

  @override
  String get currencySYP => 'Suriya lirasi';

  @override
  String get currencyTZS => 'Tanzaniya shillingi';

  @override
  String get currencyTTD => 'Trinidad va Tobago dollari';

  @override
  String get currencyTND => 'Tunis dinori';

  @override
  String get currencyUGX => 'Uganda shillingi';

  @override
  String get currencyUAH => 'Ukraina Grivnasi';

  @override
  String get currencyUYU => 'Urugvay pesosi';

  @override
  String get currencyVEF => 'Venesuela Bolivarı';

  @override
  String get currencyVND => 'Vietnam Dong';

  @override
  String get currencyYER => 'Yaman riali';

  @override
  String get currencyZMW => 'Zambiya kvachasi';
}

==> flutter_currency_picker-1.3.4.tar.gz: lib/gen_l10n/app_localization_uz.dart <==
import 'app_localization.dart';

/// The translations for Uzbek (`uz`).
class AppLocalizationsUz extends AppLocalizations {
  AppLocalizationsUz([String locale = 'uz']) : super(locale);

  @override
  String get currencyUSD => 'Amerika Qo\'shma Shtatlari Dollari';

  @override
  String get currencyEUR => 'Evro';

  @override
  String get currencyJPY => 'Yapon iyeni';

  @override
  String get currencyGBP => 'Britaniya funti';

  @override
  String get currencyAUD => 'Avstraliya dollari';

  @override
  String get currencyCAD => 'Kanada dollari';

  @override
  String get currencyCHF => 'Shveytsariya franki';

  @override
  String get currencyCNY => 'Xitoy yuan renminbi';

  @override
  String get currencyHKD => 'Gongkong dollari';

  @override
  String get currencyNZD => 'Yangi Zelandiya dollari';

  @override
  String get currencySEK => 'Shvetsiya kronasi';

  @override
  String get currencyKRW => 'Janubiy Koreya von';

  @override
  String get currencySGD => 'Singapur dollari';

  @override
  String get currencyNOK => 'Norvegiya kroni';

  @override
  String get currencyMXN => 'Meksika pesosi';

  @override
  String get currencyINR => 'Hindiston rupisi';

  @override
  String get currencyRUB => 'Rossiya rubli';

  @override
  String get currencyZAR => 'Janubiy Afrika Randi';

  @override
  String get currencyTRY => 'Turk lirasi';

  @override
  String get currencyBRL => 'Braziliya reali';

  @override
  String get currencyTWD => 'Tayvan yangi dollari';

  @override
  String get currencyDKK => 'Daniya kroni';

  @override
  String get currencyPLN => 'Polsha zlotisi';

  @override
  String get currencyTHB => 'Tailand baht';

  @override
  String get currencyIDR => 'Indoneziya rupiyasi';

  @override
  String get currencyHUF => 'Vengriya forinti';

  @override
  String get currencyCZK => 'Chexiya Korunasi';

  @override
  String get currencyILS => 'Isroil shekeli';

  @override
  String get currencyCLP => 'Chili pesosi';

  @override
  String get currencyPHP => 'Filippin peso';

  @override
  String get currencyAED => 'Amirati Dirhami';

  @override
  String get currencyCOP => 'Kolumbiya Peso';

  @override
  String get currencySAR => 'Saudiya Arabistoni Riyali';

  @override
  String get currencyMYR => 'Malayziya ringgiti';

  @override
  String get currencyRON => 'Ruminiya Leu';

  @override
  String get currencyAFN => 'Afg\'oniston afg\'oni';

  @override
  String get currencyALL => 'Alban leki';

  @override
  String get currencyDZD => 'Jazoir dinori';

  @override
  String get currencyARS => 'Argentina peso';

  @override
  String get currencyAMD => 'Arman drami';

  @override
  String get currencyAZN => 'Ozarbayjon manati';

  @override
  String get currencyBHD => 'Bahrayn dinori';

  @override
  String get currencyBDT => 'Bangladeshi Taka';

  @override
  String get currencyBBD => 'Barbados dollari';

  @override
  String get currencyBYN => 'Belarus rubli';

  @override
  String get currencyBZD => 'Beliz Dollari';

  @override
  String get currencyBMD => 'Bermud dollari';

  @override
  String get currencyBTN => 'Butan ngultrum';

  @override
  String get currencyBOB => 'Boliviya Boliviyano';

  @override
  String get currencyBAM =>
      'Bosniya va Gertsegovina konvertatsiya qilinadigan belgisi';

  @override
  String get currencyBWP => 'Botsvana pulasi';

  @override
  String get currencyBND => 'Bruney Dorussalom dollari';

  @override
  String get currencyBGN => 'Bolgariya Levi';

  @override
  String get currencyBIF => 'Burundi franki';

  @override
  String get currencyKHR => 'Kambodja rieli';

  @override
  String get currencyKYD => 'Kayman orollari dollari';

  @override
  String get currencyXAF => 'Markaziy Afrika CFA franki';

  @override
  String get currencyXOF => 'UEMOA CFA frank';

  @override
  String get currencyCDF => 'Kongo franki';

  @override
  String get currencyCRC => 'Kosta-Rika kolon';

  @override
  String get currencyDOP => 'Dominikan Respublikasi pesosi';

  @override
  String get currencyEGP => 'Misr funti';

  @override
  String get currencyETB => 'Efiopiya birri';

  @override
  String get currencyGMD => 'Gambiya dalasi';

  @override
  String get currencyGEL => 'Gruziya larisi';

  @override
  String get currencyGHS => 'Gana Sedi';

  @override
  String get currencyGTQ => 'Gvatemala quetzali';

  @override
  String get currencyGYD => 'Guyana dollari';

  @override
  String get currencyHTG => 'Gaiti gourde';

  @override
  String get currencyISK => 'Islandiya kronasi';

  @override
  String get currencyJMD => 'Yamayka dollari';

  @override
  String get currencyJOD => 'Iordaniya dinori';

  @override
  String get currencyKZT => 'Qozog\'iston tengesi';

  @override
  String get currencyKES => 'Keniya shillingi';

  @override
  String get currencyKWD => 'Quvayt dinari';

  @override
  String get currencyKGS => 'Qirg\'iziston so\'mi';

  @override
  String get currencyUZS => 'O\'zbekiston so\'mi';

  @override
  String get currencyLAK => 'Laos Kipi';

  @override
  String get currencyLRD => 'Liberiya dollari';

  @override
  String get currencyMKD => 'Makedoniya Denar';

  @override
  String get currencyMWK => 'Malavi kvacha';

  @override
  String get currencyMUR => 'Mavrikiy rupisi';

  @override
  String get currencyMDL => 'Moldova leyi';

  @override
  String get currencyMNT => 'Mo\'g\'uliston Tug\'rik';

  @override
  String get currencyMAD => 'Marokash dirhami';

  @override
  String get currencyMZN => 'Mozambik Metikali';

  @override
  String get currencyMMK => 'Myanma kyati';

  @override
  String get currencyNAD => 'Namibiya dollari';

  @override
  String get currencyNPR => 'Nepal rupisi';

  @override
  String get currencyNIO => 'Nikaragua Kordoba';

  @override
  String get currencyNGN => 'Nigeriya Naira';

  @override
  String get currencyOMR => 'Ummon riali';

  @override
  String get currencyPKR => 'Pokiston rupisi';

  @override
  String get currencyPGK => 'Papua-Yangi Gvineya Kinasi';

  @override
  String get currencyPYG => 'Paragvay Guarani';

  @override
  String get currencyPEN => 'Peru Sol';

  @override
  String get currencyQAR => 'Qatar riyali';

  @override
  String get currencyRWF => 'Ruanda franki';

  @override
  String get currencyRSD => 'Serbiya Dinari';

  @override
  String get currencySCR => 'Seychellois rupisi';

  @override
  String get currencySOS => 'Somali shillingi';

  @override
  String get currencyLKR => 'Shri-Lanka rupisi';

  @override
  String get currencySRD => 'Surinam dollari';

  @override
  String get currencySYP => 'Suriya lirasi';

  @override
  String get currencyTZS => 'Tanzaniya shillingi';

  @override
  String get currencyTTD => 'Trinidad va Tobago dollari';

  @override
  String get currencyTND => 'Tunis dinori';

  @override
  String get currencyUGX => 'Uganda shillingi';

  @override
  String get currencyUAH => 'Ukraina Grivnasi';

  @override
  String get currencyUYU => 'Urugvay pesosi';

  @override
  String get currencyVEF => 'Venesuela Bolivarı';

  @override
  String get currencyVND => 'Vietnam Dong';

  @override
  String get currencyYER => 'Yaman riali';

  @override
  String get currencyZMW => 'Zambiya kvachasi';
}
